@@ -30,7 +30,7 @@ class TQString;
 /**
 @author Joe Ferris
 */
-class KatapultItem : public TQObject {
+class KDE_EXPORT KatapultItem : public TQObject {
 	Q_OBJECT
   
 public:
